timeintervaltools.make_monophonic_percussion_score_from_nonoverlapping_intervals
================================================================================

.. autofunction:: abjad.tools.timeintervaltools.make_monophonic_percussion_score_from_nonoverlapping_intervals.make_monophonic_percussion_score_from_nonoverlapping_intervals
